.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.classify.nih_cxr14:

============
 NIH-CXR14
============

* DataModule and support code: :py:mod:`.data.classify.nih_cxr14`
* Splits:

  .. list-table::
     :align: left

     * - Config. key
       - Module
     * - ``nih-cxr14``
       - :py:mod:`.config.classify.data.nih_cxr14.default`
     * - ``nih-cxr14-100``
       - :py:mod:`.config.classify.data.nih_cxr14.first_100`
